@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication 2.20180514;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20180521'; # VERSION
+our $VERSION = '2.20180612'; # VERSION
 # ABSTRACT: Authentication Milter Module for validation of ARC signatures
 use Data::Dumper;
 use Clone qw{ clone };
@@ -30,6 +30,7 @@ sub default_config {
         'arcseal_keyfile'   => undef,
         'arcseal_headers'   => undef,
         'trusted_domains'   => [],
+        'no_strict'         => 0,
     };
 }
 
@@ -113,7 +114,7 @@ sub get_trusted_dkim_results {
                     my $entry_domain = eval{ $result->search({ 'isa' => 'subentry', 'key' => 'header.i' })->children()->[0]->value() };
                     $self->handle_exception( $@ );
                     if ( $entry_domain ) {
-                        $entry_domain =~ s/^\@//;
+                        $entry_domain =~ s/^.*\@//;
                     }
                 }
                 next RESULT if ! $entry_domain;
@@ -255,7 +256,7 @@ sub inherit_trusted_dkim_results {
                     my $entry_domain = eval{ $result->search({ 'isa' => 'subentry', 'key' => 'header.i' })->children()->[0]->value() };
                     $self->handle_exception( $@ );
                     if ( $entry_domain ) {
-                        $entry_domain =~ s/^\@//;
+                        $entry_domain =~ s/.*^\@//;
                     }
                 }
                 next RESULT if ! $entry_domain;
@@ -481,7 +482,11 @@ sub eoh_callback {
 
     my $arc;
     eval {
-        $arc = Mail::DKIM::ARC::Verifier->new();
+        my $UseStrict = 1;
+        if ( $config->{ 'no_strict' } ) {
+            $UseStrict = 0;
+        }
+        $arc = Mail::DKIM::ARC::Verifier->new( 'Strict' => $UseStrict );
         # The following requires Mail::DKIM > 0.4
         my $resolver = $self->get_object('resolver');
         Mail::DKIM::DNS::resolver($resolver);
@@ -823,7 +828,7 @@ Mail::Milter::Authentication::Handler::ARC - Authentication Milter Module for va
 
 =head1 VERSION
 
-version 2.20180521
+version 2.20180612
 
 =head1 DESCRIPTION
 
@@ -831,15 +836,16 @@ Module for validation of ARC signatures
 
 =head1 CONFIGURATION
 
-        "ARC" : {                                       | Config for the ARC Module
-            "hide_none"         : 0,                    | Hide auth line if the result is 'none'
-            "arcseal_domain"    : "example.com",        | Domain to sign ARC Seal with (not sealed if blank)
-            "arcseal_selector"  => undef,               | Selector to use for ARC Seal (not sealed if blank)
-            "arcseal_algorithm" => 'rsa-sha256',        | Algorithm to use on ARC Seal (default rsa-sha256)
-            "arcseal_key"       => undef,               | Key (base64) string to sign ARC Seal with; or
-            "arcseal_keyfile"   => undef,               | File containing ARC Seal key
-            "arcseal_headers"   => undef,               | Additional headers to cover in ARC-Message-Signature
-            "trusted_domains"   => [],                  | Trust these domains when traversing ARC chains
+        "ARC" : {                                      | Config for the ARC Module
+            "hide_none"         : 0,                   | Hide auth line if the result is 'none'
+            "arcseal_domain"    : "example.com",       | Domain to sign ARC Seal with (not sealed if blank)
+            "arcseal_selector"  : undef,               | Selector to use for ARC Seal (not sealed if blank)
+            "arcseal_algorithm" : 'rsa-sha256',        | Algorithm to use on ARC Seal (default rsa-sha256)
+            "arcseal_key"       : undef,               | Key (base64) string to sign ARC Seal with; or
+            "arcseal_keyfile"   : undef,               | File containing ARC Seal key
+            "arcseal_headers"   : undef,               | Additional headers to cover in ARC-Message-Signature
+            "trusted_domains"   : [],                  | Trust these domains when traversing ARC chains
+            "no_strict"         : 0,                   | Ignore rfc 8301 security considerations (not recommended)
         },
 
 =head1 AUTHORS
